from dataclasses import dataclass
from typing import Optional, Union

from weathercls.weatherapicom.forecast_weather.CurrentAirQuality import CurrentAirQuality
from weathercls.weatherapicom.forecast_weather.CurrentCondition import CurrentCondition


@dataclass
class Current:
    last_updated_epoch: Optional[int]
    last_updated: Optional[str]
    temp_c: Optional[float]
    temp_f: Optional[float]
    is_day: Optional[int]
    condition: Optional[CurrentCondition]
    wind_mph: Optional[float]
    wind_kph: Optional[float]
    wind_degree: Optional[float]
    wind_dir: Optional[str]
    pressure_mb: Optional[float]
    pressure_in: Optional[float]
    precip_mm: Optional[float]
    precip_in: Optional[float]
    humidity: Optional[float]
    cloud: Optional[float]
    feelslike_c: Optional[float]
    feelslike_f: Optional[float]
    vis_km: Optional[float]
    vis_miles: Optional[float]
    uv: Optional[Union[int, float]]
    gust_mph: Optional[float]
    gust_kph: Optional[float]
    air_quality: Optional[CurrentAirQuality]



from dataclasses import dataclass
from typing import Optional, List

from weathercls.weatherapicom.forecast_weather.ForecastForecastday import ForecastForecastday


@dataclass
class Forecast:
    forecastday: Optional[List[ForecastForecastday]]



from dataclasses import dataclass
from typing import Optional

from weathercls.weatherapicom.forecast_weather.Alerts import Alerts
from weathercls.weatherapicom.forecast_weather.Current import Current
from weathercls.weatherapicom.forecast_weather.Forecast import Forecast
from weathercls.weatherapicom.forecast_weather.Location import Location


@dataclass
class ForecastWeather:
    location: Optional[Location]
    current: Optional[Current]
    forecast: Optional[Forecast]
    alerts: Optional[Alerts]



from dataclasses import dataclass
from typing import Optional, Union

from weathercls.weatherapicom.forecast_weather.ForecastDayCondition import ForecastDayCondition


@dataclass
class ForecastDay:
    maxtemp_c: Optional[float]
    maxtemp_f: Optional[float]
    mintemp_c: Optional[float]
    mintemp_f: Optional[float]
    avgtemp_c: Optional[float]
    avgtemp_f: Optional[float]
    maxwind_mph: Optional[float]
    maxwind_kph: Optional[float]
    totalprecip_mm: Optional[float]
    totalprecip_in: Optional[float]
    avgvis_km: Optional[float]
    avgvis_miles: Optional[float]
    avghumidity: Optional[float]
    daily_will_it_rain: Optional[int]
    daily_chance_of_rain: Optional[float]
    daily_will_it_snow: Optional[int]
    daily_chance_of_snow: Optional[float]
    condition: Optional[ForecastDayCondition]
    uv: Optional[Union[int, float]]



from dataclasses import dataclass
from typing import Optional


@dataclass
class Location:
    name: Optional[str]
    region: Optional[str]
    country: Optional[str]
    lat: Optional[float]
    lon: Optional[float]
    tz_id: Optional[str]
    localtime_epoch: Optional[int]
    localtime: Optional[str]



from dataclasses import dataclass
from typing import Optional, Union


@dataclass
class ForecastAstro:
    sunrise: Optional[str]
    sunset: Optional[str]
    moonrise: Optional[str]
    moonset: Optional[str]
    moon_phase: Optional[str]
    moon_illumination: Optional[Union[str, int]]



from dataclasses import dataclass
from typing import List, Optional

from weathercls.weatherapicom.forecast_weather.ForecastAstro import ForecastAstro
from weathercls.weatherapicom.forecast_weather.ForecastDay import ForecastDay
from weathercls.weatherapicom.forecast_weather.ForecastHour import ForecastHour


@dataclass
class ForecastForecastday:
    date: Optional[str]
    date_epoch: Optional[int]
    day: Optional[ForecastDay]
    astro: Optional[ForecastAstro]
    hour: Optional[List[ForecastHour]]



from dataclasses import dataclass
from typing import Optional


@dataclass
class CurrentAirQuality:
    co: Optional[float]
    no2: Optional[float]
    o3: Optional[float]
    so2: Optional[float]
    pm2_5: Optional[float]
    pm10: Optional[float]
    us_epa_index: Optional[int]
    gb_defra_index: Optional[int]



def transform_to_snake_case(data):
    if isinstance(data, dict):
        return {
            (
                key.replace("-", "_") if isinstance(key, str) else key
            ): transform_to_snake_case(value)
            for key, value in data.items()
        }
    elif isinstance(data, list):
        return [transform_to_snake_case(item) for item in data]
    else:
        return data



from dataclasses import dataclass
from datetime import datetime
from typing import Optional


@dataclass
class AlertsAlert:
    headline: Optional[str]
    msgtype: Optional[str]
    severity: Optional[str]
    urgency: Optional[str]
    areas: Optional[str]
    category: Optional[str]
    certainty: Optional[str]
    event: Optional[str]
    note: Optional[str]
    effective: Optional[datetime]
    expires: Optional[datetime]
    desc: Optional[str]
    instruction: Optional[str]



from dataclasses import dataclass
from typing import Optional, Union

from weathercls.weatherapicom.forecast_weather.ForecastCondition import ForecastCondition


@dataclass
class ForecastHour:
    time_epoch: Optional[int]
    time: Optional[str]
    temp_c: Optional[float]
    temp_f: Optional[float]
    is_day: Optional[int]
    condition: Optional[ForecastCondition]
    wind_mph: Optional[float]
    wind_kph: Optional[float]
    wind_degree: Optional[float]
    wind_dir: Optional[str]
    pressure_mb: Optional[float]
    pressure_in: Optional[float]
    precip_mm: Optional[float]
    precip_in: Optional[float]
    humidity: Optional[float]
    cloud: Optional[float]
    feelslike_c: Optional[float]
    feelslike_f: Optional[float]
    windchill_c: Optional[float]
    windchill_f: Optional[float]
    heatindex_c: Optional[float]
    heatindex_f: Optional[float]
    dewpoint_c: Optional[float]
    dewpoint_f: Optional[float]
    will_it_rain: Optional[int]
    chance_of_rain: Optional[float]
    will_it_snow: Optional[int]
    chance_of_snow: Optional[float]
    vis_km: Optional[float]
    vis_miles: Optional[float]
    gust_mph: Optional[float]
    gust_kph: Optional[float]
    uv: Optional[Union[int, float]]



from dataclasses import dataclass
from typing import List, Optional

from weathercls.weatherapicom.forecast_weather.AlertsAlert import AlertsAlert


@dataclass
class Alerts:
    alert: Optional[List[AlertsAlert]]
